@@ -12,6 +12,7 @@ from .serializers import (
     FIDO2RegistrationSerializer,
     FIDO2AuthenticateSerializer,
     TrustedDeviceSerializer,
+    BackupCodesGenerateSerializer,
     BackupCodesSerializer,
     BackupCodeAuthSerializer
 )
@@ -101,15 +102,22 @@ class UserKeyViewSet(
         serializer.save(key_type=UserKey.KeyType.DEVICE, user=self.request.user)
         return Response(serializer.data)
 
-    @action(detail=False, methods=["post"], name="Set backup codes")
+    @action(detail=False, methods=["get", "post"], name="Set backup codes")
     def backup_codes(self, request):
         """
         Make one time backup codes for user
         Only one set up codes may exist, requesting new ones will delete existing
+
+        GET method is optional for generating the codes in advance before commiting to the database
+        POST method will commit to the database. If codes is not set, it will generate them.
         """
+        if request.method == "GET":
+             codes = UserKey.generate_backup_codes()
+             serializer = BackupCodesGenerateSerializer({"codes": codes})
+             return Response(serializer.data)
         serializer = self.get_serializer(data=request.data)
         serializer.is_valid(raise_exception=True)
-        serializer.save(key_type=UserKey.KeyType.DEVICE, user=self.request.user)
+        serializer.save(key_type=UserKey.KeyType.BACKUP_CODES, user=self.request.user)
         return Response(serializer.data)
 
 
